@@ -1,9 +1,11 @@
 knearest <-
 function(D,P,n_clust)
-{     
-      if (requireNamespace("FNN", quietly = TRUE)) {
+{
+    if(!requireNamespace("FNN", quietly = TRUE))
+    {
+       install.packages("FNN", quiet = TRUE)
+    }
 	  knD<-FNN::knnx.index(D,P,k=(n_clust+1), algo="kd_tree")
-	  }
 	  knD=knD*(knD!=row(knD))
 	  que=which(knD[,1]>0)
 	  for (i in que)
@@ -11,6 +13,6 @@ function(D,P,n_clust)
 	       knD[i,1]=0
 		   #print(i)
 	  }
-      return(knD[,2:(n_clust+1)]) 
-       	  
+      return(knD[,2:(n_clust+1)])
+
 }
